@@ -7,6 +7,7 @@
 from ..note import Arc
 from ..note import NoteGroup
 from random import randint
+from ...exception import AffNoteValueError
 
 
 def arc_crease_line(
@@ -14,9 +15,11 @@ def arc_crease_line(
         x_range: float,
         y_range: float,
         count: int,
-        mode='m'
+        mode='m',
+        easing='s'
 ) -> NoteGroup:
     """
+    :param easing:
     :param base:
     :param x_range:
     :param y_range:
@@ -35,6 +38,7 @@ def arc_crease_line(
             each.fromy = currenty
             each.tox += x_range
             each.toy += y_range
+            each.slideeasing = easing
             x_range = -x_range
             y_range = -y_range
             currentx = each.tox
@@ -45,12 +49,14 @@ def arc_crease_line(
             arclist[i - 1].tox += x_range
             arclist[i].fromy += y_range
             arclist[i - 1].toy += y_range
+            arclist[i].slideeasing = easing
+            arclist[i - 1].slideeasing = easing
     else:
         raise ValueError('Invalid mode:' + mode)
     return arclist
 
 
-def arc_rain(original_t: int, dest_t: int, step: int):
+def arc_rain(original_t: int, dest_t: int, step: int, length: int = None):
     def max_x(y: int) -> int:
         return int(-0.5 * y + 200)
 
@@ -58,13 +64,15 @@ def arc_rain(original_t: int, dest_t: int, step: int):
         return int(0.5 * y)
 
     destgroup = NoteGroup()
+    if length is None:
+        length = step
 
     for current_time in range(original_t, dest_t, step):
         rand_y = randint(0, 100)
         rand_x = randint(min_x(rand_y), max_x(rand_y))
         destgroup.append(Arc(
             current_time,
-            current_time + step,
+            current_time + length,
             (rand_x - 50) / 100,
             (rand_x - 50) / 100,
             's',
@@ -79,5 +87,26 @@ def arc_rain(original_t: int, dest_t: int, step: int):
 def arc_slice_by_count(arc: Arc, count: int, start: int = None, stop: int = None):
     start = start if start is not None else arc.time
     stop = stop if stop is not None else arc.totime
-    step = int((stop - start) / count)
-    return arc[start:stop:step]
+    if stop < start:
+        raise AffNoteValueError(
+            'stop time before start time'
+        )
+    step = (stop - start) / count
+    if step < 1:
+        step = 1
+        count = arc.totime - arc.time
+    destgroup = NoteGroup()
+    for i in range(count):
+        destgroup.append(Arc(
+            start + i * step,
+            start + (i + 1) * step,
+            arc[start + i * step][0],
+            arc[start + (i + 1) * step][0],
+            's',
+            arc[start + i * step][1],
+            arc[start + (i + 1) * step][1],
+            arc.color,
+            arc.isskyline,
+            fx=arc.fx
+        ))
+    return destgroup
